use crate::events::Event;
use crate::handles::online_users_update::send_online_users_resp;
use crate::handles::redis::remove_this_connection;
use tokio::sync::mpsc::UnboundedSender;

pub async fn handle_connection_error(
    from_id: &str,
    event_sender: &UnboundedSender<Event>,
) {
    println!("开始处理用户id: {} 的连接错误", from_id);

    // 发送关闭连接事件
    event_sender.send(Event::CloseConnection(from_id.to_string())).unwrap();

    // 从 Redis 中移除该用户的信息
    if let Err(e) = remove_this_connection(from_id).await {
        println!("从 Redis 中移除用户信息时出错: {}", e);
    }

    // 准备更新用户链接
    if let Err(e) = send_online_users_resp().await {
        println!("在处理新用户id {} 之时广播，处理在线用户列表出错了：{:?}", from_id, e);
    } else {
        println!("成功将用户id {} 退出广播至其余用户", from_id);
    }
}